DoubleEndedFallibleIterator

Trait DoubleEndedFallibleIterator 

pub trait DoubleEndedFallibleIterator: FallibleIterator {
    // Required method
    fn next_back(&mut self) -> Result<Option<Self::Item>, Self::Error>;

    // Provided methods
    fn rfold<B, F>(self, init: B, f: F) -> Result<B, Self::Error>
       where Self: Sized,
             F: FnMut(B, Self::Item) -> Result<B, Self::Error> { ... }
    fn try_rfold<B, E, F>(&mut self, init: B, f: F) -> Result<B, E>
       where Self: Sized,
             E: From<Self::Error>,
             F: FnMut(B, Self::Item) -> Result<B, E> { ... }
}
A fallible iterator able to yield elements from both ends.

Required Methods

fn next_back(&mut self) -> Result<Option<Self::Item>, Self::Error>

Advances the end of the iterator, returning the last value.

Provided Methods

fn rfold<B, F>(self, init: B, f: F) -> Result<B, Self::Error>
where Self: Sized, F: FnMut(B, Self::Item) -> Result<B, Self::Error>,

Applies a function over the elements of the iterator in reverse order, producing a single final value.

fn try_rfold<B, E, F>(&mut self, init: B, f: F) -> Result<B, E>
where Self: Sized, E: From<Self::Error>, F: FnMut(B, Self::Item) -> Result<B, E>,

Applies a function over the elements of the iterator in reverse, producing a single final value.

This is used as the “base” of many methods on DoubleEndedFallibleIterator.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<I> DoubleEndedFallibleIterator for &mut I

Source

impl<I> DoubleEndedFallibleIterator for Box<I>

Available on crate features alloc or std only.

Implementors